% File src/library/stats/man/addmargins.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{addmargins}

\alias{addmargins}
\concept{totals}
\concept{margins}

\title{
  Puts Arbitrary Margins on Multidimensional Tables or Arrays
}

\description{
  与えられたテーブルに対して
  どの分類因子が一つ又は複数のレベルで計算されるべきマージンを拡大する
  かを指示できる．
  例えば最初の次元に対して和と平均，二番目に対して中央値を作る．
  結果のテーブルはそうすると最初の次元に対して二つの余分のレベルを持ち，
  二番目に対しては一つの余分のレベルを持つ．
  既定ではテーブル中の全てのマージンに渡って和を取る．
  他の可能性はマージンが計算される順序に依存する結果を
  与えるかもしれない．
  これは関数からプリントされた出力中でフラグが立つ．
}

\usage{
addmargins(A, margin = seq_along(dim(A)), FUN = sum, quiet = FALSE)
}

\arguments{
  \item{A}{テーブル又は配列．関数は
    \code{A} の \code{"dim"} と \code{"dimnames"} 属性の存在を利用する．}
  \item{margin}{マージンを作る次元のベクトル．
    マージンは \code{margin} 中で指定された次元の順序で作られる．}
  \item{FUN}{
    \code{margin} と同じ長さのリストで，その各要素は
    関数か関数のりスト．
    リストの要素の名前は結果の次元名中にレベルとして現れる．
    名前のないリスト要素は名前が作られる：
    関数の名前かテーブル中の位置に基づき作られた名前．}
  \item{quiet}{マージンが計算される順序を告げるメッセージを抑制する論理値．}
}

\details{
  もしマージンを整形する関数が可換でなければ，
  結果はマージンが計算される順序に依存する．
  マージンの注釈は
  \code{FUN} リストの名前を用いてなされる．
}

\value{
  \code{A} と同じ数の次元を持つテーブルもしくは配列であるが，
  \code{margin} 中で述べられた余分の次元のレベルを持つ．
  各次元に加えられたレベルの数は
  \code{FUN} 中の項目の長さである．マージンの計算の順序を持つ
  メッセージがプリントされる．
}
\author{
  Bendix Carstensen, Steno Diabetes Center & Department of
  Biostatistics, University of Copenhagen,
  \url{http://www.biostat.ku.dk/~bxc}, autumn 2003.
  マージンの命名は Duncan Murdoch により拡張された．
}

\seealso{
  \code{\link{table}}, \code{\link{ftable}}, \code{\link{margin.table}}.
}

\examples{
Aye <- sample(c("Yes", "Si", "Oui"), 177, replace = TRUE)
Bee <- sample(c("Hum", "Buzz"), 177, replace = TRUE)
Sea <- sample(c("White", "Black", "Red", "Dead"), 177, replace = TRUE)
(A <- table(Aye, Bee, Sea))
addmargins(A)
\dontshow{
stopifnot(is.table(addmargins(A)))
}
ftable(A)
ftable(addmargins(A))

# 非可換関数 - 結果のテーブルの間の違いに注意：
ftable(addmargins(A, c(1, 3),
       FUN = list(Sum = sum, list(Min = min, Max = max))))
ftable(addmargins(A, c(3, 1),
       FUN = list(list(Min = min, Max = max), Sum = sum)))

# パーセントを計算する際に N を返す必要がある異常な関数
sqsm <- function(x) sum(x)^2/100
B <- table(Sea, Bee)
round(sweep(addmargins(B, 1, list(list(All = sum, N = sqsm))), 2,
            apply(B, 2, sum)/100, "/"), 1)
round(sweep(addmargins(B, 2, list(list(All = sum, N = sqsm))), 1,
            apply(B, 1, sum)/100, "/"), 1)

# Bee に関する総計は先ず Bee のマージンを整形する必要がある
mB <-  addmargins(B, 2, FUN = list(list(Total = sum)))
round(ftable(sweep(addmargins(mB, 1, list(list(All = sum, N = sqsm))), 2,
                   apply(mB, 2, sum)/100, "/")), 1)

## table+margins のゼロのプリント 
set.seed(1)
x <- sample( 1:7, 20, replace = TRUE)
y <- sample( 1:7, 20, replace = TRUE)
tx <- addmargins( table(x, y) )
print(tx, zero.print = ".")
}
\keyword{manip}
\keyword{array}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/addmargins.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{addmargins}
%
%\alias{addmargins}
%\concept{totals}
%\concept{margins}
%
%\title{
%  Puts Arbitrary Margins on Multidimensional Tables or Arrays
%}
%
%\description{
%  For a given table one can specify which of the classifying factors to
%  expand by one or more levels to hold margins to be calculated.  One may for
%  example form sums and means over the first dimension and medians over the
%  second.  The resulting table will then have two extra levels for the first
%  dimension and one extra level for the second.  The default is to sum over
%  all margins in the table.  Other possibilities may give results that
%  depend on the order in which the margins are computed.  This is flagged
%  in the printed output from the function.
%}
%
%\usage{
%addmargins(A, margin = seq_along(dim(A)), FUN = sum, quiet = FALSE)
%}
%
%\arguments{
%  \item{A}{table or array.  The function uses the presence of the
%    \code{"dim"} and \code{"dimnames"} attributes of \code{A}.}
%  \item{margin}{vector of dimensions over which to form margins.  Margins
%    are formed in the order in which dimensions are specified in
%    \code{margin}.}
%  \item{FUN}{list of the same length as \code{margin}, each element of
%    the list being either a function or a list of functions.  Names of
%    the list elements will appear as levels in dimnames of the result.
%    Unnamed list elements will have names constructed:  the name
%    of a function or a constructed name based on the position in the table.}
%  \item{quiet}{logical which suppresses the message telling the order in
%    which the margins were computed.}
%}
%
%\details{
%  If the functions used to form margins are not commutative the result
%  depends on the order in which margins are computed.  Annotation
%  of margins is done via naming the \code{FUN} list.
%}
%
%\value{
%  A table or array with the same number of dimensions as \code{A}, but
%  with extra levels of the dimensions mentioned in \code{margin}.  The
%  number of levels added to each dimension is the length of the entries
%  in \code{FUN}.  A message with the order of computation of margins is
%  printed.
%}
%\author{
%  Bendix Carstensen, Steno Diabetes Center & Department of
%  Biostatistics, University of Copenhagen,
%  \url{http://www.biostat.ku.dk/~bxc}, autumn 2003.
%  Margin naming enhanced by Duncan Murdoch.
%}
%
%\seealso{
%  \code{\link{table}}, \code{\link{ftable}}, \code{\link{margin.table}}.
%}
%
%\examples{
%Aye <- sample(c("Yes", "Si", "Oui"), 177, replace = TRUE)
%Bee <- sample(c("Hum", "Buzz"), 177, replace = TRUE)
%Sea <- sample(c("White", "Black", "Red", "Dead"), 177, replace = TRUE)
%(A <- table(Aye, Bee, Sea))
%addmargins(A)
%\dontshow{
%stopifnot(is.table(addmargins(A)))
%}
%ftable(A)
%ftable(addmargins(A))
%
%# Non-commutative functions - note differences between resulting tables:
%ftable(addmargins(A, c(1, 3),
%       FUN = list(Sum = sum, list(Min = min, Max = max))))
%ftable(addmargins(A, c(3, 1),
%       FUN = list(list(Min = min, Max = max), Sum = sum)))
%
%# Weird function needed to return the N when computing percentages
%sqsm <- function(x) sum(x)^2/100
%B <- table(Sea, Bee)
%round(sweep(addmargins(B, 1, list(list(All = sum, N = sqsm))), 2,
%            apply(B, 2, sum)/100, "/"), 1)
%round(sweep(addmargins(B, 2, list(list(All = sum, N = sqsm))), 1,
%            apply(B, 1, sum)/100, "/"), 1)
%
%# A total over Bee requires formation of the Bee-margin first:
%mB <-  addmargins(B, 2, FUN = list(list(Total = sum)))
%round(ftable(sweep(addmargins(mB, 1, list(list(All = sum, N = sqsm))), 2,
%                   apply(mB, 2, sum)/100, "/")), 1)
%
%## Zero.Printing table+margins:
%set.seed(1)
%x <- sample( 1:7, 20, replace = TRUE)
%y <- sample( 1:7, 20, replace = TRUE)
%tx <- addmargins( table(x, y) )
%print(tx, zero.print = ".")
%}
%\keyword{manip}
%\keyword{array}
%
%\encoding{UTF-8}
%