% File src/library/stats/man/integrate.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{integrate}
\alias{integrate}
\alias{print.integrate}%@%\alias{一次元関数の数値積分}
\title{Integration of One-Dimensional Functions}
\description{
  有限もしくは無限区間上の一変数関数の適応的求積法．
}
\usage{
integrate(f, lower, upper, \dots, subdivisions = 100L,
          rel.tol = .Machine$double.eps^0.25, abs.tol = rel.tol,
          stop.on.error = TRUE, keep.xy = FALSE, aux = NULL)
}
\arguments{
  \item{f}{
    数値の第一引数を取り同じ長さの数値ベクトルを返す \R 関数．
    有限でない値を返すとエラーになる．}
  \item{lower, upper}{積分範囲．無限であっても良い．}
  \item{\dots}{\code{f} に渡される追加引数．}
  \item{subdivisions}{副区間の最大数．}
  \item{rel.tol}{要求される相対精度．}
  \item{abs.tol}{要求される絶対精度．}
  \item{stop.on.error}{論理値．もし真(既定)ならばエラーは関数を停止する．
    もし偽ならある種のエラーは
    \code{message} 成分中の警告と共に結果を与える．}
  \item{keep.xy}{未使用．S との互換性のため．}
  \item{aux}{未使用．S との互換性のため．}
}
\details{
  \code{\dots} の後の引数は正確にマッチする必要があることを注意する．

  もし一方か両方の限界が無限ならば，無限区間は有限区間にマップされる．

  有限区間に対しては，大局的に適応的な区間の分割が
  Wynn のイプシロンアルゴリズムによる補外との関連で用いられ，
  基本的なステプは Gauss--Kronrod 求積法を用いる．

  もし \code{abs.tol <= 0} ならば \code{rel.tol} は
  \code{max(50*.Machine$double.eps, 0.5e-28)} 以下であってはならない ．
}
\note{
  全ての数値的積分ルーチンと同じく，これらは
  関数を点の集合上で評価する．
  もし関数がほとんどその範囲全てで近似的に定数(特にゼロ)ならば，
  結果とそのエラー推定値は極めて不正確であり得る．

  無限区間で積分するときは，端点を大きな値にする代わりに，それを明確に指示する．
  これは正しい解を得るチャンスを増やす -- 無限区間でその積分が
  有限である関数はその区間の殆どでゼロに近いはずである．

  有限個の点の集合上での値が他の場所での関数の挙動の
  良い反映であるためには関数は，
  例えば恐らく少数のジャンプ点や積分特異点を除いて微分可能
  である等の，良い挙動を持つ必要がある．

  \code{f} は入力のベクトルを受け入れ，そして
  これらの点での関数評価のベクトルを作りださなければならない．
  関数 \code{\link{Vectorize}} は
  \code{f} をこの形式に変換するのに役立つかもしれない．
}
\value{
  クラス \code{"integrate"} のりストで次の成分を持つ
  \item{value}{積分の最終推定値．}
  \item{abs.error}{絶対誤差の絶対値の推定値．}
  \item{subdivisions}{分割の過程で作られた副区間の数．}
  \item{message}{\code{"OK"} 又はエラーメッセージを与える文字列．}
  \item{call}{マッチした呼び出し．}
}

\source{
  R. Piessens and E. deDoncker--Kapenga に依る
  QUADPACK ルーチン \code{dqags} と \code{dqagi}，
  Netlib から入手可能．
}

\references{
  R. Piessens, E. deDoncker--Kapenga, C. Uberhuber, D. Kahaner (1983)
  \emph{Quadpack: a Subroutine Package for Automatic Integration};
  Springer Verlag.
}
\examples{
integrate(dnorm, -1.96, 1.96)
integrate(dnorm, -Inf, Inf)

## 収束が遅い積分
integrand <- function(x) {1/((x+1)*sqrt(x))}
integrate(integrand, lower = 0, upper = Inf)

## もし本当に無限大から0までの積分が欲しければ，こうしてはならない
integrate(integrand, lower = 0, upper = 10)
integrate(integrand, lower = 0, upper = 100000)
integrate(integrand, lower = 0, upper = 1000000, stop.on.error = FALSE)

## ある種の関数はベクトル入力を適切に処理できない
f <- function(x) 2.0
try(integrate(f, 0, 1))
integrate(Vectorize(f), 0, 1)  ## 正しい
integrate(function(x) rep(2.0, length(x)), 0, 1)  ## 正しい

## もし誤用されると積分は失敗する
integrate(dnorm, 0, 2)
integrate(dnorm, 0, 20)
integrate(dnorm, 0, 200)
integrate(dnorm, 0, 2000)
integrate(dnorm, 0, 20000) ## 多くのシステムで失敗する
integrate(dnorm, 0, Inf)   ## 動作する
}
\keyword{math}
\keyword{utilities}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/integrate.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{integrate}
%\alias{integrate}
%\alias{print.integrate}
%\title{Integration of One-Dimensional Functions}
%\description{
%  Adaptive quadrature of functions of one variable over a finite or
%  infinite interval.
%}
%\usage{
%integrate(f, lower, upper, \dots, subdivisions = 100L,
%          rel.tol = .Machine$double.eps^0.25, abs.tol = rel.tol,
%          stop.on.error = TRUE, keep.xy = FALSE, aux = NULL)
%}
%\arguments{
%  \item{f}{an \R function taking a numeric first argument and returning
%    a numeric vector of the same length.  Returning a non-finite element will
%    generate an error.}
%  \item{lower, upper}{the limits of integration.  Can be infinite.}
%  \item{\dots}{additional arguments to be passed to \code{f}.}
%  \item{subdivisions}{the maximum number of subintervals.}
%  \item{rel.tol}{relative accuracy requested.}
%  \item{abs.tol}{absolute accuracy requested.}
%  \item{stop.on.error}{logical. If true (the default) an error stops the
%    function.  If false some errors will give a result with a warning in
%    the \code{message} component.}
%  \item{keep.xy}{unused.  For compatibility with S.}
%  \item{aux}{unused.  For compatibility with S.}
%}
%\details{
%  Note that arguments after \code{\dots} must be matched exactly.
%
%  If one or both limits are infinite, the infinite range is mapped onto
%  a finite interval.
%
%  For a finite interval, globally adaptive interval subdivision is used
%  in connection with extrapolation by Wynn's Epsilon algorithm, with the
%  basic step being Gauss--Kronrod quadrature.
%
%  \code{rel.tol} cannot be less than \code{max(50*.Machine$double.eps,
%    0.5e-28)} if \code{abs.tol <= 0}.
%}
%\note{
%  Like all numerical integration routines, these evaluate the function
%  on a finite set of points.  If the function is approximately constant
%  (in particular, zero) over nearly all its range it is possible that
%  the result and error estimate may be seriously wrong.
%
%  When integrating over infinite intervals do so explicitly, rather than
%  just using a large number as the endpoint.  This increases the chance
%  of a correct answer -- any function whose integral over an infinite
%  interval is finite must be near zero for most of that interval.
%
%  For values at a finite set of points to be a fair reflection of the
%  behaviour of the function elsewhere, the function needs to be
%  well-behaved, for example differentiable except perhaps for a small
%  number of jumps or integrable singularities.
%
%  \code{f} must accept a vector of inputs and produce a vector of function
%  evaluations at those points.  The \code{\link{Vectorize}} function
%  may be helpful to convert \code{f} to this form.
%}
%\value{
%  A list of class \code{"integrate"} with components
%  \item{value}{the final estimate of the integral.}
%  \item{abs.error}{estimate of the modulus of the absolute error.}
%  \item{subdivisions}{the number of subintervals produced in the
%    subdivision process.}
%  \item{message}{\code{"OK"} or a character string giving the error message.}
%  \item{call}{the matched call.}
%}
%
%\source{
%  Based on QUADPACK routines \code{dqags} and \code{dqagi} by
%  R. Piessens and E. deDoncker--Kapenga, available from Netlib.
%}
%
%\references{
%  R. Piessens, E. deDoncker--Kapenga, C. Uberhuber, D. Kahaner (1983)
%  \emph{Quadpack: a Subroutine Package for Automatic Integration};
%  Springer Verlag.
%}
%\examples{
%integrate(dnorm, -1.96, 1.96)
%integrate(dnorm, -Inf, Inf)
%
%## a slowly-convergent integral
%integrand <- function(x) {1/((x+1)*sqrt(x))}
%integrate(integrand, lower = 0, upper = Inf)
%
%## don't do this if you really want the integral from 0 to Inf
%integrate(integrand, lower = 0, upper = 10)
%integrate(integrand, lower = 0, upper = 100000)
%integrate(integrand, lower = 0, upper = 1000000, stop.on.error = FALSE)
%
%## some functions do not handle vector input properly
%f <- function(x) 2.0
%try(integrate(f, 0, 1))
%integrate(Vectorize(f), 0, 1)  ## correct
%integrate(function(x) rep(2.0, length(x)), 0, 1)  ## correct
%
%## integrate can fail if misused
%integrate(dnorm, 0, 2)
%integrate(dnorm, 0, 20)
%integrate(dnorm, 0, 200)
%integrate(dnorm, 0, 2000)
%integrate(dnorm, 0, 20000) ## fails on many systems
%integrate(dnorm, 0, Inf)   ## works
%}
%\keyword{math}
%\keyword{utilities}
%
%\encoding{UTF-8}
%
